library(dismo)

setwd("/Data/Dropbox/Grimm.Potts.Research/GBIF")


# Koppen
koppen <- read.table("Koeppen-Geiger-ASCII.txt",header=T)
koppen$Cls

lev <- levels(koppen$Cls)
koppen$Cls <- as.numeric(koppen$Cls)
koppen2 <- rasterFromXYZ(koppen[,c(2,1,3)])
plot(koppen2)

gen <- c("Bubbia",
         "Drimys",
         "Belliolum",
         #"Exospermum", # No records found for this genus
         "Pseudowintera",
         "Takhtajania",
         "Tasmannia",
         "Zygogynum")
# Treat as Bubbia as Zynogynum
# Drimys in America
# Tasmannia in Australia
# Any samples in Africa or Europe must be removed. 

# Bar graph of each genus per koppen zone. 
# Remove spatial bias
# Wanted genera
# Takhtajania - Madagascan
# Tasmannia - mostly labelled as Drimys. Anything in Australia and Pacific is Tasmania.
# Drimys - South and North American
# Pseudowintera - exclusively New Zealand
# Zygogynum - includes Bubbia, Belliolum, Exospermum & Zygogynum. 

?gbif
i<-1
dat <- list()

### Run once
# for (i.gen in gen) {
#   dat[[i.gen]] <- gbif(genus=i.gen,geo=TRUE)
# }
# for (i.gen in gen) {
#   write.csv(dat[[i.gen]], file=paste("RawGBIFdata/",i.gen,".csv",sep=""),row.names=F)
# }



sort(colnames(dat[[i.gen]]))

# The gbif column names shift and sway to an unpredictable beat, so can't hard code (hence cti2)
colsToInclude <- c("genus","scientificName","lat","lon","coordinateUncertaintyInMeters","fullCountry","continent","recordedBy","occurrenceRemarks")

# Do some summarising and only keep useful records
for (i.gen in gen) {
  dat2 <- read.csv(paste("RawGBIFdata/",i.gen,".csv",sep=""))
  # Removing missing lat/long
  cti2 <- colsToInclude[colsToInclude%in%colnames(dat2)]
  dat2 <- dat2[,cti2]
  dat2 <- dat2[rowSums(is.na(dat2[,c("lon","lat")]))==0,]
  tutu <- lev[extract(koppen2,dat2[,c("lon","lat")])]
  dat2 <- cbind(Koppen=tutu,dat2)
  write.csv(dat2,file=paste("KoppenGBIFdata/",i.gen,".csv",sep=""),row.names=F)
}



# Any samples in Africa or Europe must be removed. 
# Bar graph of each genus per koppen zone. 
# Remove spatial bias

### Wanted genera
# Takhtajania - Madagascan
# Tasmannia - mostly labelled as Drimys. Anything in Australia and Pacific is Tasmania.
# Drimys - South and North American
# Pseudowintera - exclusively New Zealand
# Zygogynum - includes Bubbia, Belliolum, Exospermum & Zygogynum. 


tak <- read.csv("KoppenGBIFdata/Takhtajania.csv")
plot(koppen2)
points(tak[,c("lon","lat")]) # all in Madagascar (upper portion)
dim(tak)
# Removing spatial bias using grid sampling
tak2 <- tak[rownames(gridSample(tak[,c("lon","lat")],koppen2,n=1)),]
takkop <- table(tak2$Koppen)


drim <- read.csv("KoppenGBIFdata/Drimys.csv")
drim2 <- subset(drim,continent%in%c("NORTH_AMERICA","SOUTH_AMERICA"))
plot(koppen2)

points(drim2[,c("lon","lat")]) 
drim3 <- drim2[rownames(gridSample(drim2[,c("lon","lat")],koppen2,n=1)),]
drimkop <- table(drim3$Koppen)

pseuwin <- read.csv("KoppenGBIFdata/Pseudowintera.csv")
plot(koppen2)
points(pseuwin[,c("lon","lat")]) # all in Madagascar (upper portion)
pseuwin <- subset(pseuwin,fullCountry=="New Zealand")
pseuwin2 <- pseuwin[rownames(gridSample(pseuwin[,c("lon","lat")],koppen2,n=1)),]
dim(pseuwin)
dim(pseuwin2)
pseuwinkop <- table(pseuwin2$Koppen)

# Zygogynum - includes Bubbia, Belliolum, Exospermum & Zygogynum. 
bub <- read.csv("KoppenGBIFdata/Bubbia.csv")
bell <- read.csv("KoppenGBIFdata/Belliolum.csv")
zyg <- read.csv("KoppenGBIFdata/Zygogynum.csv")
ncol(bub);ncol(bell);ncol(zyg)

plot(koppen2)

# Tasmannia - mostly labelled as Drimys. Anything in Australia and Pacific is Tasmania.



